@@ -14,12 +14,12 @@ struct _CamelEwsStoreSummaryPrivate {
 	gboolean dirty;
 	gchar *path;
 	/* Note: We use the *same* strings in both of these hash tables, and
-	   only id_fname_hash has g_free() hooked up as the destructor func.
-	   So entries must always be removed from fname_id_hash *first*. */
+	 * only id_fname_hash has g_free() hooked up as the destructor func.
+	 * So entries must always be removed from fname_id_hash *first*. */
 	GHashTable *id_fname_hash;
 	GHashTable *fname_id_hash;
 	GStaticRecMutex s_lock;
-	
+
 	GFileMonitor *monitor_delete;
 };
 
@@ -124,17 +124,21 @@ load_id_fname_hash (CamelEwsStoreSummary *ews_summary)
 
 /* we only care about delete and ignore create */
 static void
-monitor_delete_cb (GFileMonitor *monitor, GFile *file, GFile *other_file, GFileMonitorEvent event, gpointer user_data)
+monitor_delete_cb (GFileMonitor *monitor,
+                   GFile *file,
+                   GFile *other_file,
+                   GFileMonitorEvent event,
+                   gpointer user_data)
 {
 	CamelEwsStoreSummary *ews_summary = (CamelEwsStoreSummary *) user_data;
 
 	if (event == G_FILE_MONITOR_EVENT_DELETED) {
-		S_LOCK(ews_summary);
+		S_LOCK (ews_summary);
 
 		if (ews_summary->priv->key_file)
 			camel_ews_store_summary_clear (ews_summary);
 
-		S_UNLOCK(ews_summary);
+		S_UNLOCK (ews_summary);
 	}
 }
 
@@ -166,39 +170,39 @@ camel_ews_store_summary_new (const gchar *path)
 
 gboolean
 camel_ews_store_summary_load (CamelEwsStoreSummary *ews_summary,
-			      GError **error)
+                              GError **error)
 {
 	CamelEwsStoreSummaryPrivate *priv = ews_summary->priv;
 	gboolean ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_load_from_file	(priv->key_file,
 					 priv->path,
 					 0, error);
 
 	load_id_fname_hash (ews_summary);
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gboolean
 camel_ews_store_summary_save (CamelEwsStoreSummary *ews_summary,
-			      GError **error)
+                              GError **error)
 {
 	CamelEwsStoreSummaryPrivate *priv = ews_summary->priv;
 	gboolean ret = TRUE;
 	GFile *file;
 	gchar *contents = NULL;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	if (!priv->dirty)
 		goto exit;
 
 	contents = g_key_file_to_data	(priv->key_file, NULL,
-		       			 NULL);
+					 NULL);
 	file = g_file_new_for_path	(priv->path);
 	ret = g_file_replace_contents	(file, contents, strlen (contents),
 					 NULL, FALSE, G_FILE_CREATE_PRIVATE,
@@ -207,7 +211,7 @@ camel_ews_store_summary_save (CamelEwsStoreSummary *ews_summary,
 	priv->dirty = FALSE;
 
 exit:
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	g_free (contents);
 	return ret;
@@ -217,13 +221,13 @@ gboolean
 camel_ews_store_summary_clear (CamelEwsStoreSummary *ews_summary)
 {
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_free (ews_summary->priv->key_file);
 	ews_summary->priv->key_file = g_key_file_new ();
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return TRUE;
 }
@@ -233,14 +237,14 @@ camel_ews_store_summary_remove (CamelEwsStoreSummary *ews_summary)
 {
 	gint ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	if (ews_summary->priv->key_file)
 		camel_ews_store_summary_clear (ews_summary);
 
 	ret = g_unlink (ews_summary->priv->path);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return (ret == 0);
 }
@@ -252,7 +256,9 @@ struct subfolder_match {
 };
 
 static void
-match_subfolder (gpointer key, gpointer value, gpointer user_data)
+match_subfolder (gpointer key,
+                 gpointer value,
+                 gpointer user_data)
 {
 	struct subfolder_match *sm = user_data;
 
@@ -261,7 +267,7 @@ match_subfolder (gpointer key, gpointer value, gpointer user_data)
 }
 
 /* Must be called with the summary lock held, and gets to keep
-   both its string arguments */
+ * both its string arguments */
 static void ews_ss_hash_replace (CamelEwsStoreSummary *ews_summary,
 				 gchar *folder_id, gchar *full_name,
 				 gboolean recurse)
@@ -275,9 +281,9 @@ static void ews_ss_hash_replace (CamelEwsStoreSummary *ews_summary,
 	ofname = g_hash_table_lookup (ews_summary->priv->id_fname_hash,
 				      folder_id);
 	/* Remove the old fullname->id hash entry *iff* it's pointing
-	   to this folder id. */
+	 * to this folder id. */
 	if (ofname) {
-		char *ofid = g_hash_table_lookup (ews_summary->priv->fname_id_hash,
+		gchar *ofid = g_hash_table_lookup (ews_summary->priv->fname_id_hash,
 						  ofname);
 		if (!strcmp (folder_id, ofid)) {
 			g_hash_table_remove (ews_summary->priv->fname_id_hash,
@@ -290,7 +296,7 @@ static void ews_ss_hash_replace (CamelEwsStoreSummary *ews_summary,
 	g_hash_table_insert (ews_summary->priv->fname_id_hash, full_name, folder_id);
 
 	/* Replace, not insert. The difference is that it frees the *old* folder_id
-	   key, not the new one which we just inserted into fname_id_hash too. */
+	 * key, not the new one which we just inserted into fname_id_hash too. */
 	g_hash_table_replace (ews_summary->priv->id_fname_hash, folder_id, full_name);
 
 	if (sm.match) {
@@ -311,10 +317,10 @@ static void ews_ss_hash_replace (CamelEwsStoreSummary *ews_summary,
 
 void
 camel_ews_store_summary_set_folder_name (CamelEwsStoreSummary *ews_summary,
-					 const gchar *folder_id,
-					 const gchar *display_name)
+                                         const gchar *folder_id,
+                                         const gchar *display_name)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_string	(ews_summary->priv->key_file, folder_id,
 				 "DisplayName", display_name);
@@ -322,21 +328,20 @@ camel_ews_store_summary_set_folder_name (CamelEwsStoreSummary *ews_summary,
 	ews_ss_hash_replace (ews_summary, g_strdup (folder_id), NULL, TRUE);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
-
 void
 camel_ews_store_summary_new_folder (CamelEwsStoreSummary *ews_summary,
-				    const gchar *folder_id,
-				    const gchar *parent_fid,
-				    const gchar *change_key,
-				    const gchar *display_name,
-				    guint64 folder_type,
-				    guint64 folder_flags,
-				    guint64 total)
+                                    const gchar *folder_id,
+                                    const gchar *parent_fid,
+                                    const gchar *change_key,
+                                    const gchar *display_name,
+                                    guint64 folder_type,
+                                    guint64 folder_flags,
+                                    guint64 total)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_string (ews_summary->priv->key_file, folder_id,
 			       "ParentFolderId", parent_fid);
@@ -355,16 +360,15 @@ camel_ews_store_summary_new_folder (CamelEwsStoreSummary *ews_summary,
 
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
-
 void
 camel_ews_store_summary_set_parent_folder_id (CamelEwsStoreSummary *ews_summary,
-					      const gchar *folder_id,
-					      const gchar *parent_id)
+                                              const gchar *folder_id,
+                                              const gchar *parent_id)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	if (parent_id)
 		g_key_file_set_string (ews_summary->priv->key_file, folder_id,
@@ -377,310 +381,309 @@ camel_ews_store_summary_set_parent_folder_id (CamelEwsStoreSummary *ews_summary,
 
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
-camel_ews_store_summary_set_change_key	(CamelEwsStoreSummary *ews_summary,
-					 const gchar *folder_id,
-					 const gchar *change_key)
+camel_ews_store_summary_set_change_key (CamelEwsStoreSummary *ews_summary,
+                                         const gchar *folder_id,
+                                         const gchar *change_key)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_string	(ews_summary->priv->key_file, folder_id,
 				 "ChangeKey", change_key);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
 camel_ews_store_summary_set_sync_state (CamelEwsStoreSummary *ews_summary,
-					const gchar *folder_id,
-					const gchar *sync_state)
+                                        const gchar *folder_id,
+                                        const gchar *sync_state)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_string	(ews_summary->priv->key_file, folder_id,
 				 "SyncState", sync_state);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
 camel_ews_store_summary_set_folder_flags (CamelEwsStoreSummary *ews_summary,
-					  const gchar *folder_id,
-					  guint64 flags)
+                                          const gchar *folder_id,
+                                          guint64 flags)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_uint64	(ews_summary->priv->key_file, folder_id,
 				 "Flags", flags);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
 camel_ews_store_summary_set_folder_unread (CamelEwsStoreSummary *ews_summary,
-					   const gchar *folder_id,
-					   guint64 unread)
+                                           const gchar *folder_id,
+                                           guint64 unread)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_uint64	(ews_summary->priv->key_file, folder_id,
 				 "UnRead", unread);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
 camel_ews_store_summary_set_folder_total (CamelEwsStoreSummary *ews_summary,
-					  const gchar *folder_id,
-					  guint64 total)
+                                          const gchar *folder_id,
+                                          guint64 total)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_uint64	(ews_summary->priv->key_file, folder_id,
 				 "Total", total);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
 camel_ews_store_summary_set_folder_type (CamelEwsStoreSummary *ews_summary,
-					 const gchar *folder_id,
-					 guint64 ews_folder_type)
+                                         const gchar *folder_id,
+                                         guint64 ews_folder_type)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_uint64	(ews_summary->priv->key_file, folder_id,
 				 "FolderType", ews_folder_type);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 void
 camel_ews_store_summary_store_string_val (CamelEwsStoreSummary *ews_summary,
-					  const gchar *key,
-					  const gchar *value)
+                                          const gchar *key,
+                                          const gchar *value)
 {
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	g_key_file_set_string	(ews_summary->priv->key_file, STORE_GROUP_NAME,
 				 key, value);
 	ews_summary->priv->dirty = TRUE;
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 }
 
 gchar *
 camel_ews_store_summary_get_folder_name (CamelEwsStoreSummary *ews_summary,
-					 const gchar *folder_id,
-					 GError **error)
+                                         const gchar *folder_id,
+                                         GError **error)
 {
 	gchar *ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_string	(ews_summary->priv->key_file, folder_id,
 					 "DisplayName", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gchar *
 camel_ews_store_summary_get_folder_full_name (CamelEwsStoreSummary *ews_summary,
-					      const gchar *folder_id,
-					      GError **error)
+                                              const gchar *folder_id,
+                                              GError **error)
 {
 	gchar *ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_hash_table_lookup (ews_summary->priv->id_fname_hash, folder_id);
 
 	if (ret)
 		ret = g_strdup (ret);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gchar *
 camel_ews_store_summary_get_parent_folder_id (CamelEwsStoreSummary *ews_summary,
-					      const gchar *folder_id,
-					      GError **error)
+                                              const gchar *folder_id,
+                                              GError **error)
 {
 	gchar *ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_string	(ews_summary->priv->key_file, folder_id,
 					 "ParentFolderId", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gchar *
 camel_ews_store_summary_get_change_key (CamelEwsStoreSummary *ews_summary,
-					const gchar *folder_id,
-					GError **error)
+                                        const gchar *folder_id,
+                                        GError **error)
 {
 	gchar *ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_string	(ews_summary->priv->key_file, folder_id,
 					 "ChangeKey", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gchar *
 camel_ews_store_summary_get_sync_state (CamelEwsStoreSummary *ews_summary,
-					const gchar *folder_id,
-					GError **error)
+                                        const gchar *folder_id,
+                                        GError **error)
 {
 	gchar *ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_string	(ews_summary->priv->key_file, folder_id,
 					 "SyncState", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 guint64
 camel_ews_store_summary_get_folder_flags (CamelEwsStoreSummary *ews_summary,
-					  const gchar *folder_id,
-					  GError **error)
+                                          const gchar *folder_id,
+                                          GError **error)
 {
 	guint64 ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_uint64	(ews_summary->priv->key_file, folder_id,
 					 "Flags", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
-
 guint64
 camel_ews_store_summary_get_folder_unread (CamelEwsStoreSummary *ews_summary,
-					   const gchar *folder_id,
-					   GError **error)
+                                           const gchar *folder_id,
+                                           GError **error)
 {
 	guint64 ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_uint64	(ews_summary->priv->key_file, folder_id,
 					 "UnRead", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 guint64
 camel_ews_store_summary_get_folder_total (CamelEwsStoreSummary *ews_summary,
-					  const gchar *folder_id,
-					  GError **error)
+                                          const gchar *folder_id,
+                                          GError **error)
 {
 	guint64 ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_uint64	(ews_summary->priv->key_file, folder_id,
 					 "Total", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 guint64
 camel_ews_store_summary_get_folder_type (CamelEwsStoreSummary *ews_summary,
-					 const gchar *folder_id,
-					 GError **error)
+                                         const gchar *folder_id,
+                                         GError **error)
 {
 	guint64 ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_uint64	(ews_summary->priv->key_file, folder_id,
 					 "FolderType", error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gchar *
-camel_ews_store_summary_get_string_val	(CamelEwsStoreSummary *ews_summary,
-					 const gchar *key,
-					 GError **error)
+camel_ews_store_summary_get_string_val (CamelEwsStoreSummary *ews_summary,
+                                         const gchar *key,
+                                         GError **error)
 {
 	gchar *ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_get_string	(ews_summary->priv->key_file, STORE_GROUP_NAME,
 					 key, error);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 GSList *
 camel_ews_store_summary_get_folders (CamelEwsStoreSummary *ews_summary,
-				     const gchar *prefix)
+                                     const gchar *prefix)
 {
 	GSList *folders = NULL;
 	gchar **groups = NULL;
 	gsize length;
-	int prefixlen = 0;
+	gint prefixlen = 0;
 	gint i;
 
 	if (prefix)
-		prefixlen = strlen(prefix);
+		prefixlen = strlen (prefix);
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	groups = g_key_file_get_groups (ews_summary->priv->key_file, &length);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	for (i = 0; i < length; i++) {
-		if (!g_ascii_strcasecmp (groups [i], STORE_GROUP_NAME))
+		if (!g_ascii_strcasecmp (groups[i], STORE_GROUP_NAME))
 			continue;
 		if (prefixlen) {
 			const gchar *fname = g_hash_table_lookup (ews_summary->priv->id_fname_hash, groups[i]);
 
-			if (!fname || strncmp(fname, prefix, prefixlen) ||
+			if (!fname || strncmp (fname, prefix, prefixlen) ||
 			    (fname[prefixlen] && fname[prefixlen] != '/'))
 				continue;
 		}
-		folders = g_slist_append (folders, g_strdup (groups [i]));
+		folders = g_slist_append (folders, g_strdup (groups[i]));
 	}
 
 	g_strfreev (groups);
@@ -689,13 +692,13 @@ camel_ews_store_summary_get_folders (CamelEwsStoreSummary *ews_summary,
 
 gboolean
 camel_ews_store_summary_remove_folder (CamelEwsStoreSummary *ews_summary,
-				       const gchar *folder_id,
-				       GError **error)
+                                       const gchar *folder_id,
+                                       GError **error)
 {
 	gboolean ret = FALSE;
 	gchar *full_name;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	full_name = g_hash_table_lookup (ews_summary->priv->id_fname_hash, folder_id);
 	if (!full_name)
@@ -710,38 +713,39 @@ camel_ews_store_summary_remove_folder (CamelEwsStoreSummary *ews_summary,
 	ews_summary->priv->dirty = TRUE;
 
  unlock:
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
 
 gchar *
 camel_ews_store_summary_get_folder_id_from_name (CamelEwsStoreSummary *ews_summary,
-						 const gchar *folder_name)
+                                                 const gchar *folder_name)
 {
 	gchar *folder_id;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	folder_id = g_hash_table_lookup (ews_summary->priv->fname_id_hash, folder_name);
 	if (folder_id)
 		folder_id = g_strdup (folder_id);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return folder_id;
 }
 
 gboolean
-camel_ews_store_summary_has_folder (CamelEwsStoreSummary *ews_summary, const gchar *folder_id)
+camel_ews_store_summary_has_folder (CamelEwsStoreSummary *ews_summary,
+                                    const gchar *folder_id)
 {
 	gboolean ret;
 
-	S_LOCK(ews_summary);
+	S_LOCK (ews_summary);
 
 	ret = g_key_file_has_group (ews_summary->priv->key_file, folder_id);
 
-	S_UNLOCK(ews_summary);
+	S_UNLOCK (ews_summary);
 
 	return ret;
 }
